@@ -14,63 +14,69 @@ build_time_vars = {'ABIFLAGS': '',
  'BINLIBDEST': '/usr/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-fno-semantic-interposition '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'BUILDEXE': '.exe',
- 'BUILDPYTHON': 'python.exe',
+ 'BUILDEXE': '',
+ 'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -fno-semantic-interposition -march=x86-64 '
-           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -fcf-protection -march=x86-64 '
-           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -fcf-protection',
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+           '-fno-semantic-interposition',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+ 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
                      '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-fcf-protection -fno-semantic-interposition',
- 'CONFIGURE_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+                     '-fcf-protection -g '
+                     '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                     '-fno-semantic-interposition',
+ 'CONFIGURE_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c99 -Wextra '
                             '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                      '-fno-semantic-interposition',
- 'CONFIGURE_LDFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
- 'CONFIG_ARGS': "'--prefix=/usr' '-enable-shared' '--with-computed-gotos' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
                 "'--with-lto' '--enable-ipv6' '--with-system-expat' "
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--with-tzpath=/usr/share/zoneinfo' "
-                "'ax_cv_c_float_words_bigendian=no' 'CFLAGS=-march=x86-64 "
-                '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=x86-64 "
+                '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
-                "-fcf-protection -fno-semantic-interposition' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
-                "-fno-semantic-interposition'",
+                '-fcf-protection -g '
+                '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                "-fno-semantic-interposition' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/data/tmp/aur-temp/python39/src/Python-3.9.9/coverage.info',
- 'COVERAGE_REPORT': '/data/tmp/aur-temp/python39/src/Python-3.9.9/lcov-report',
+ 'COVERAGE_INFO': '/build/python39/src/Python-3.9.19/coverage.info',
+ 'COVERAGE_REPORT': '/build/python39/src/Python-3.9.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -126,7 +132,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -297,6 +303,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -441,7 +448,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STRLCPY': 0,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
@@ -459,6 +466,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -543,23 +551,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.9',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.9',
- 'INSTALL': '/bin/install -c',
- 'INSTALL_DATA': '/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/bin/install -c',
- 'INSTALL_SCRIPT': '/bin/install -c',
- 'INSTALL_SHARED': '/bin/install -c -m 755',
+ 'INSTALL': '/usr/bin/install -c',
+ 'INSTALL_DATA': '/usr/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c',
+ 'INSTALL_SHARED': '/usr/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-fno-semantic-interposition '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-fno-semantic-interposition '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDVERSION': '3.9',
  'LIBC': '',
@@ -595,7 +601,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/bin/mkdir -p',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
@@ -653,25 +659,30 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
- 'PYTHON_FOR_BUILD': './python.exe -E',
+ 'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic '
-                             '-O3 -pipe -fno-plt -fexceptions         '
+                             '-O2 -pipe -fno-plt -fexceptions         '
                              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
                              '-fno-semantic-interposition -march=x86-64 '
-                             '-mtune=generic -O3 -pipe -fno-plt '
+                             '-mtune=generic -O2 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection '
-                             '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                             '-fno-semantic-interposition -march=x86-64 '
+                             '-mtune=generic -O2 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -flto=4 '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                             '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
@@ -680,18 +691,23 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+              '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -fno-semantic-interposition -march=x86-64 '
-              '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection',
- 'PY_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+              '-fcf-protection -g '
+              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+              '-Wformat -Werror=format-security         '
+              '-fstack-clash-protection -fcf-protection -g '
+              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+              '-Wformat -Werror=format-security         '
+              '-fstack-clash-protection -fcf-protection -g '
+              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+              '-fno-semantic-interposition',
+ 'PY_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                      '-flto-partition=none -g -std=c99 -Wextra '
                      '-Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
@@ -699,53 +715,62 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-Wall -march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -fno-semantic-interposition -march=x86-64 '
-                   '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
+                   '-O2 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -march=x86-64 -mtune=generic -O3 -pipe '
-                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wformat -Werror=format-security         '
-                   '-fstack-clash-protection -fcf-protection -flto=4 '
-                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
-                   '-g -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
+                   '-O2 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -flto-partition=none -g -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-fno-semantic-interposition '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=4 '
+                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto '
                     '-fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-fno-semantic-interposition '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'PY_LDFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+ 'PY_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                       '-flto-partition=none -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=x86-64 -mtune=generic -O3 -pipe '
+                        '-O3 -Wall -march=x86-64 -mtune=generic -O2 -pipe '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
                         '-fno-semantic-interposition -march=x86-64 '
-                        '-mtune=generic -O3 -pipe -fno-plt '
+                        '-mtune=generic -O2 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection '
-                        '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                        '-fno-semantic-interposition -march=x86-64 '
+                        '-mtune=generic -O2 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -flto=4 '
-                        '-fuse-linker-plugin -ffat-lto-objects '
-                        '-flto-partition=none -g -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
+                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
@@ -758,7 +783,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -799,11 +824,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9 '
-               './python.exe',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9 '
-               './python.exe ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19 ./python '
+               './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -825,8 +849,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/data/tmp/aur-temp/python39/src/Python-3.9.9',
- 'abs_srcdir': '/data/tmp/aur-temp/python39/src/Python-3.9.9',
+ 'abs_builddir': '/build/python39/src/Python-3.9.19',
+ 'abs_srcdir': '/build/python39/src/Python-3.9.19',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
